EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Jobs_GetJobHistoryForEnvironments',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Executions_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the specified jobs in the system, as long as they only contain the specified environments.'
GO


IF OBJECT_ID('[Jobs_GetJobHistoryForEnvironments]') IS NOT NULL DROP PROCEDURE [Jobs_GetJobHistoryForEnvironments]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Jobs_GetJobHistoryForEnvironments]
(
    @EnvironmentId_Csv VARCHAR(MAX),
    @Execution_Count INT = NULL,
    @Server_Id INT = NULL,
    @ExecutionStatus_Code CHAR(1) = NULL
)   
AS
BEGIN

    SET NOCOUNT ON

    IF @Execution_Count IS NOT NULL
        SET ROWCOUNT @Execution_Count;

    WITH ENV AS (SELECT [Environment_Id] = CAST([Value_Text] AS INT) FROM [CsvToTable](@EnvironmentId_Csv, ','))
	SELECT E.*
	  FROM [Executions_Extended] E
     WHERE E.[Job_Id] IS NOT NULL
       AND (@Server_Id IS NULL OR E.[Server_Id] = @Server_Id)
       AND (@ExecutionStatus_Code IS NULL OR E.[ExecutionStatus_Code] = @ExecutionStatus_Code)
       AND NOT EXISTS(
             SELECT 1
               FROM [EnvironmentServers] ES
               LEFT JOIN ENV
                      ON ENV.[Environment_Id] = ES.[Environment_Id]
              WHERE ES.[Server_Id] = E.[Server_Id]
                AND ENV.[Environment_Id] IS NULL)
       AND NOT EXISTS(
             SELECT 1
               FROM [JobEnvironments] JE
               LEFT JOIN ENV
                      ON ENV.[Environment_Id] = JE.[Environment_Id]
              WHERE JE.[Job_Id] = E.[Job_Id]
                AND ENV.[Environment_Id] IS NULL)
     ORDER BY E.[Execution_Id] DESC

END
GO

GRANT EXECUTE ON [Jobs_GetJobHistoryForEnvironments] TO [OtterUser_Role]