EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Servers_CreateOrUpdateServer',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Server_Id',
    /* Description_Text        */ 'Creates a new server, or updates an existing one. If the Roles or Environments are not passed in as a parameter, then they will not be changed; however, passing in an empty string will remove the server from the corresponding groups.'
GO


IF OBJECT_ID('[Servers_CreateOrUpdateServer]') IS NOT NULL DROP PROCEDURE [Servers_CreateOrUpdateServer]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Servers_CreateOrUpdateServer]
(
	@Server_Name NVARCHAR(50),
	@RoutineExecutionType_Code CHAR(1),
    @ServerRoleIds_Csv NVARCHAR(MAX) = NULL,
	@EnvironmentIds_Csv NVARCHAR(MAX) = NULL,
	@Agent_Configuration XML = NULL,
	@Raft_Id INT = NULL,
	@Active_Indicator YNINDICATOR = NULL,
	@CollectOperations_Csv VARCHAR(MAX) = NULL,
    @Server_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@Server_Id IS NULL)
	BEGIN
		INSERT INTO [Servers] 
		(
			[Server_Name],
			[RoutineExecutionType_Code],
			[Agent_Configuration],
			[Raft_Id],
            [ServerStatus_Code],
			[Active_Indicator],
			[CollectOperations_Csv]
		)
		VALUES
		(
			@Server_Name,
			@RoutineExecutionType_Code,
			@Agent_Configuration,
			@Raft_Id,
            'UNKWN',
			COALESCE(@Active_Indicator, 'Y'),
			@CollectOperations_Csv
		)
		SET @Server_Id = SCOPE_IDENTITY()

		-- EXEC [Events_RaiseEvent] 'ENVNWS', NULL, @Server_Id
	END
	ELSE
	BEGIN
		UPDATE [Servers]
			SET [Server_Name] = @Server_Name,
				[RoutineExecutionType_Code] = @RoutineExecutionType_Code,
				[Agent_Configuration] = COALESCE(@Agent_Configuration, [Agent_Configuration]),
				[Raft_Id] = @Raft_Id,
				[Active_Indicator] = COALESCE(@Active_Indicator, [Active_Indicator]),
				[CollectOperations_Csv] = COALESCE(@CollectOperations_Csv, [CollectOperations_Csv])
			WHERE [Server_Id] = @Server_Id

		--EXEC [Events_RaiseEvent] 'ENVMDS', NULL, @Server_Id
	END

    IF @ServerRoleIds_Csv IS NOT NULL
    BEGIN
        
        DELETE [ServerRoleServers] WHERE [Server_Id] = @Server_Id

        INSERT INTO [ServerRoleServers] ([ServerRole_Id], [Server_Id])
        SELECT [Value_Text], @Server_Id 
          FROM dbo.CsvToTable(@ServerRoleIds_Csv, ',')

    END

	IF @EnvironmentIds_Csv IS NOT NULL

        DELETE [EnvironmentServers] WHERE [Server_Id] = @Server_Id

        INSERT INTO [EnvironmentServers] ([Environment_Id], [Server_Id])
        SELECT [Value_Text], @Server_Id 
          FROM dbo.CsvToTable(@EnvironmentIds_Csv, ',')

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Servers_CreateOrUpdateServer] TO [OtterUser_Role]
